panel.disparity: Combined wireframe and cloud panel

View source: R/disparity_through_time.R

panel.disparityR Documentation

Combined wireframe and cloud panel

Description

[Deprecated]

Plots the provided data on 2-D surfaces within a 3-D framework. See disparity_through_time().

Usage

panel.disparity(x, y, z, groups, subscripts, ...)

Arguments

x, y, z, groups, subscripts, ...

Same as for lattice::panel.cloud()

Value

No return value, plots the results of both lattice::panel.cloud() and lattice::panel.wireframe().

Life cycle

This function is soft deprecated as of deeptime version 2.4.0. It will be removed in a future version.


deeptime documentation built on July 10, 2026, 9:08 a.m.